<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//ro_RO

$LANG=array();


$LANG['backup'][0]="SQL Dump"; 
$LANG['backup'][1]="XML Dump"; 
$LANG['backup'][11]="Mărime"; 
$LANG['backup'][13]="Vizualizează/Descarcă"; 
$LANG['backup'][16]="Sigur doriți să suprascrieți baza de date cu acest fișier de siguranță:"; 
$LANG['backup'][17]="Șterge fișierul"; 
$LANG['backup'][18]="Salvare a bazei de date"; 
$LANG['backup'][19]="Acum"; 
$LANG['backup'][21]="Fișierul există deja"; 
$LANG['backup'][22]="Octetul nu poate fi găsit"; 
$LANG['backup'][23]="Eroare MySQL incepând de la"; 
$LANG['backup'][24]="Redirecționare automată, altfel faceți click"; 

$LANG['bookmark'][1]="Semn de carte"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Nu ați salvat încă semnul de carte"; 
$LANG['bookmark'][4]="Semn de carte nou"; 
$LANG['bookmark'][5]="Semn de carte public"; 
$LANG['bookmark'][6]="Default view"; 

$LANG['buttons'][0]="Caută"; 
$LANG['buttons'][2]="OK"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="Instalează"; 
$LANG['buttons'][5]="Dezinstalează"; 
$LANG['buttons'][6]="Șterge"; 
$LANG['buttons'][7]="Actualizează"; 
$LANG['buttons'][8]="Adaugă"; 
$LANG['buttons'][9]="Conectare"; 
$LANG['buttons'][10]="Deconectare"; 
$LANG['buttons'][11]="Următorul"; 
$LANG['buttons'][12]="Anterior"; 
$LANG['buttons'][13]="Înapoi"; 
$LANG['buttons'][14]="Modifică"; 
$LANG['buttons'][15]="Programa"; 
$LANG['buttons'][16]="Golește"; 
$LANG['buttons'][17]="Invert the selection"; 
$LANG['buttons'][18]="Bifează tot"; 
$LANG['buttons'][19]="Debifează tot"; 
$LANG['buttons'][20]="Mută"; 
$LANG['buttons'][21]="Restaură"; 
$LANG['buttons'][22]="Curăța"; 
$LANG['buttons'][23]="Afișează"; 
$LANG['buttons'][24]="În sus"; 
$LANG['buttons'][25]="În jos"; 
$LANG['buttons'][27]="Current page in PDF"; 
$LANG['buttons'][28]="Current page in SLK"; 
$LANG['buttons'][29]="All pages in PDF"; 
$LANG['buttons'][30]="All pages in SLK"; 
$LANG['buttons'][31]="Export"; 
$LANG['buttons'][32]="Încheiere"; 
$LANG['buttons'][33]="Start"; 
$LANG['buttons'][34]="Anulează"; 
$LANG['buttons'][37]="Import"; 
$LANG['buttons'][38]="Deblochează"; 
$LANG['buttons'][39]="Înlocuiește"; 
$LANG['buttons'][40]="Afișează tot"; 
$LANG['buttons'][41]="Activează"; 
$LANG['buttons'][42]="Dezactivează"; 
$LANG['buttons'][43]="Răsfoire"; 
$LANG['buttons'][44]="Current page in CSV"; 
$LANG['buttons'][45]="All pages in CSV"; 
$LANG['buttons'][46]="Înapoi"; 
$LANG['buttons'][47]="Înainte"; 
$LANG['buttons'][48]="Transfer"; 
$LANG['buttons'][49]="Păstrează"; 
$LANG['buttons'][50]="Testează"; 
$LANG['buttons'][51]="Salvează"; 
$LANG['buttons'][52]="Încarcă"; 
$LANG['buttons'][53]="Clean"; 
$LANG['buttons'][55]="First"; 
$LANG['buttons'][56]="Last"; 
$LANG['buttons'][57]="Execute"; 
$LANG['buttons'][58]="Update"; 
$LANG['buttons'][59]="Dissociate"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="D"; 
$LANG['calendarD'][1]="L"; 
$LANG['calendarD'][2]="M"; 
$LANG['calendarD'][3]="M"; 
$LANG['calendarD'][4]="J"; 
$LANG['calendarD'][5]="V"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Duminică"; 
$LANG['calendarDay'][1]="Luni"; 
$LANG['calendarDay'][2]="Marți"; 
$LANG['calendarDay'][3]="Miercuri"; 
$LANG['calendarDay'][4]="Joi"; 
$LANG['calendarDay'][5]="Vineri"; 
$LANG['calendarDay'][6]="Sâmbătă"; 

$LANG['calendarM'][0]="Ianuarie"; 
$LANG['calendarM'][1]="Februarie"; 
$LANG['calendarM'][2]="Martie"; 
$LANG['calendarM'][3]="Aprilie"; 
$LANG['calendarM'][4]="Mai"; 
$LANG['calendarM'][5]="Iunie"; 
$LANG['calendarM'][6]="Iulie"; 
$LANG['calendarM'][7]="August"; 
$LANG['calendarM'][8]="Septembrie"; 
$LANG['calendarM'][9]="Octombrie"; 
$LANG['calendarM'][10]="Noiembrie"; 
$LANG['calendarM'][11]="Decembrie"; 

$LANG['cartridges'][0]="Cartuș"; 
$LANG['cartridges'][7]="Nici un cartuș găsit"; 
$LANG['cartridges'][9]="Fără cartuș"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Tip cartuș"; 
$LANG['cartridges'][13]="Nou"; 
$LANG['cartridges'][14]="Uzat"; 
$LANG['cartridges'][15]="Uzat"; 
$LANG['cartridges'][16]="Cartuș(e)"; 
$LANG['cartridges'][20]="Nou"; 
$LANG['cartridges'][21]="Uzat"; 
$LANG['cartridges'][22]="Uzat"; 
$LANG['cartridges'][24]="Data schimbării"; 
$LANG['cartridges'][27]="Pornit"; 
$LANG['cartridges'][29]="Gol"; 
$LANG['cartridges'][32]="Modele de imprimante compatibile"; 
$LANG['cartridges'][33]="Cartușe uzate"; 
$LANG['cartridges'][34]="Nici un cartuș liber"; 
$LANG['cartridges'][35]="Cartușe uzate"; 
$LANG['cartridges'][37]="Ribon"; 
$LANG['cartridges'][39]="Contor imprimantă"; 
$LANG['cartridges'][40]="Durata medie cât a fost pe stoc"; 
$LANG['cartridges'][41]="Durata medie de utilizare"; 
$LANG['cartridges'][42]="Nr. mediu de pagini printate"; 

$LANG['central'][2]="Ultimul"; 
$LANG['central'][4]="Nici un eveniment"; 
$LANG['central'][5]="Acasă"; 
$LANG['central'][6]="Logout"; 
$LANG['central'][7]="Ajutor"; 
$LANG['central'][8]="Adăugări"; 
$LANG['central'][9]="Probleme în curs de rezolvare"; 
$LANG['central'][10]="Probleme noi"; 
$LANG['central'][12]="Vedere personală"; 
$LANG['central'][13]="Vedere globală"; 
$LANG['central'][14]="Vedere de grup"; 
$LANG['central'][18]="Your tickets to close"; 
$LANG['central'][19]="Your tickets to validate"; 

$LANG['choice'][0]="Nu"; 
$LANG['choice'][1]="Da"; 

$LANG['common'][0]="Fara nume"; 
$LANG['common'][1]="Inventar"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Afișează obiectele șterse"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Producator"; 
$LANG['common'][6]="Numele template-ului"; 
$LANG['common'][7]="Alege un template"; 
$LANG['common'][8]="Administreaza template-uri..."; 
$LANG['common'][9]="Adauga template..."; 
$LANG['common'][10]="Responsabil tehnic"; 
$LANG['common'][11]="Afisare simplificata"; 
$LANG['common'][12]="Setari"; 
$LANG['common'][13]="Template"; 
$LANG['common'][14]="Templates"; 
$LANG['common'][15]="Locatie"; 
$LANG['common'][16]="Nume"; 
$LANG['common'][17]="Tip"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="Numar de serie"; 
$LANG['common'][20]="Numar de inventar"; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="Model"; 
$LANG['common'][23]="Operatia a fost efectuata cu succes"; 
$LANG['common'][24]="Nu ati selectat nici un element sau operatia nu este bine definita"; 
$LANG['common'][25]="Observatii"; 
$LANG['common'][26]="Ultima actualizare"; 
$LANG['common'][27]="Data"; 
$LANG['common'][28]="Sters"; 
$LANG['common'][29]="Plugins"; 
$LANG['common'][30]="Obiect nou"; 
$LANG['common'][31]="Template gol"; 
$LANG['common'][32]="Caracteristici"; 
$LANG['common'][33]="Total"; 
$LANG['common'][34]="Utilizator"; 
$LANG['common'][35]="Grup"; 
$LANG['common'][36]="Categorie"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="Multiplica elementul in concordanta cu numarul conexiunilor"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="Avertizari prin E-mail"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="Prenume"; 
$LANG['common'][44]="Valoare implicită"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="În curs de desfășurare"; 
$LANG['common'][48]="Nume"; 
$LANG['common'][49]="Nimic"; 
$LANG['common'][50]="Confirmați ștergerea?"; 
$LANG['common'][51]="Nume complet"; 
$LANG['common'][52]="Server"; 
$LANG['common'][53]="Lista"; 
$LANG['common'][54]="Obiectul nu poate fi gasit"; 
$LANG['common'][55]="Sigur doriti sa stergeti acest element?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Titlu"; 
$LANG['common'][58]="Valoarea maxima"; 
$LANG['common'][59]="Global"; 
$LANG['common'][60]="Activ"; 
$LANG['common'][61]="Eroare necunoscuta"; 
$LANG['common'][62]="Alta metoda"; 
$LANG['common'][63]="Eroare"; 
$LANG['common'][64]="Manager"; 
$LANG['common'][65]="Interfata"; 
$LANG['common'][66]="Toate"; 
$LANG['common'][67]="Altele"; 
$LANG['common'][68]="Fundal"; 
$LANG['common'][69]="Portret"; 
$LANG['common'][70]="Obiect adăugat cu succes"; 
$LANG['common'][71]="Obiect actualizat cu succes"; 
$LANG['common'][72]="Obiect șters cu succes"; 
$LANG['common'][73]="Obiect curățat cu succes"; 
$LANG['common'][74]="Obiect reparat cu succes"; 
$LANG['common'][75]="Nu aveți dreptul de a face elementul recursiv în această entitate"; 
$LANG['common'][76]="Public"; 
$LANG['common'][77]="Privat"; 
$LANG['common'][78]="Setati public"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="Se incarca..."; 
$LANG['common'][81]="Don't show deleted items"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="Flag change forbidden. Linked items found."; 
$LANG['common'][85]="Change visibility in the child entities"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="New card"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Not installed"; 
$LANG['common'][90]="Object"; 
$LANG['common'][91]="Can't change this attribute. It's inherited from its parent."; 
$LANG['common'][92]="Alternate username"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Volume"; 
$LANG['computers'][1]="Free percentage"; 
$LANG['computers'][2]="Free size"; 
$LANG['computers'][3]="Global size"; 
$LANG['computers'][4]="File system"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Add a volume"; 
$LANG['computers'][8]="Volumes"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Introdus"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="Nici un monitor conectat."; 
$LANG['computers'][38]="Nici o imprimanta conectata"; 
$LANG['computers'][39]="Imprimanta(e)"; 
$LANG['computers'][40]="Monitor/Monitoare"; 
$LANG['computers'][46]="Dispozitive"; 
$LANG['computers'][47]="Nici un dispozitiv conectat"; 
$LANG['computers'][48]="Actualizare locatie. Elementele relationate au fost mutate in aceeasi locatie."; 
$LANG['computers'][49]="Alternate username updated. The connected items have been updated using this alternate username."; 
$LANG['computers'][50]="Utilizator sau grup actualizat."; 
$LANG['computers'][51]="Sursa de actualizare"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="Nici un telefon conectat"; 
$LANG['computers'][55]="Telefon"; 
$LANG['computers'][56]="Statut actualizat. Elementele conectate au fost actualizate utilizand acest statut."; 

$LANG['connect'][0]="Conexiuni directe"; 
$LANG['connect'][1]="Neconectat."; 
$LANG['connect'][15]="Actualizare automata pentru urmatoarele elemente"; 
$LANG['connect'][16]="Atentie!! Urmatoarele obiecte ale celor 2 hardwares nu se potrivesc"; 

$LANG['consumables'][0]="Consumabil"; 
$LANG['consumables'][1]="In stoc"; 
$LANG['consumables'][2]="Referinta"; 
$LANG['consumables'][7]="Nici un consumabil gasit"; 
$LANG['consumables'][9]="Nici un consumabil"; 
$LANG['consumables'][12]="Tipul comsumabilului"; 
$LANG['consumables'][13]="Nou"; 
$LANG['consumables'][15]="Uzat"; 
$LANG['consumables'][16]="Consumabil(e)"; 
$LANG['consumables'][20]="Nou"; 
$LANG['consumables'][22]="Uzat"; 
$LANG['consumables'][23]="Stare"; 
$LANG['consumables'][26]="Data folosirii"; 
$LANG['consumables'][32]="Preda"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Locatie stoc"; 
$LANG['consumables'][37]="Inapoi la stocuri"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="Contract expired since the"; 
$LANG['contract'][1]="Contract with notice since the"; 

$LANG['crontask'][0]="Automatic actions"; 
$LANG['crontask'][1]="Synchronize equipments from OCSNG"; 
$LANG['crontask'][2]="Send alarms on cartridges"; 
$LANG['crontask'][3]="Send alarms on consumables"; 
$LANG['crontask'][4]="Send alarms on expired licenses"; 
$LANG['crontask'][5]="Send alarms on contracts"; 
$LANG['crontask'][6]="Send alarms on financial information"; 
$LANG['crontask'][7]="Clean old logs"; 
$LANG['crontask'][8]="Database optimization"; 
$LANG['crontask'][9]="Retrieve email (Mail receivers)"; 
$LANG['crontask'][10]="Check the MySQL replica"; 
$LANG['crontask'][11]="Check for new updates"; 
$LANG['crontask'][12]="Clean expired sessions"; 
$LANG['crontask'][13]="Clean generated graphics"; 
$LANG['crontask'][14]="Automatic tickets closing"; 
$LANG['crontask'][15]="Not solved tickets"; 
$LANG['crontask'][31]="Disabled"; 
$LANG['crontask'][32]="Scheduled"; 
$LANG['crontask'][33]="Running"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Run mode"; 
$LANG['crontask'][37]="Run frequency"; 
$LANG['crontask'][38]="Run period"; 
$LANG['crontask'][39]="Number of email to retrieve"; 
$LANG['crontask'][40]="Last run"; 
$LANG['crontask'][41]="Next run"; 
$LANG['crontask'][42]="As soon as possible"; 
$LANG['crontask'][43]="No action pending"; 
$LANG['crontask'][44]="Action completed, partially processed"; 
$LANG['crontask'][45]="Action completed, fully processed"; 
$LANG['crontask'][46]="Action completed, no processing required"; 
$LANG['crontask'][47]="Last run list"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Run count"; 
$LANG['crontask'][51]="Minimal time"; 
$LANG['crontask'][52]="Maximal time"; 
$LANG['crontask'][53]="Average time"; 
$LANG['crontask'][55]="Minimal count"; 
$LANG['crontask'][56]="Maximal count"; 
$LANG['crontask'][57]="Average count"; 
$LANG['crontask'][58]="Total count"; 
$LANG['crontask'][59]="Average speed"; 
$LANG['crontask'][60]="System lock"; 
$LANG['crontask'][61]="Disabled plugin"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="adauga o noua componenta"; 
$LANG['devices'][1]="Unitate disk"; 
$LANG['devices'][2]="Placa grafica"; 
$LANG['devices'][3]="Placa de retea"; 
$LANG['devices'][4]="Procesor"; 
$LANG['devices'][5]="Placa de baza"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Placa de sunet"; 
$LANG['devices'][19]="Drives"; 
$LANG['devices'][20]="Butoane de control"; 
$LANG['devices'][21]="Alte componente"; 
$LANG['devices'][22]="Carcasa"; 
$LANG['devices'][23]="Sursa alimentare"; 
$LANG['devices'][24]="implicit"; 
$LANG['devices'][25]="Adaugati o componenta"; 
$LANG['devices'][26]="Sterge o componenta"; 

$LANG['device_case'][0]="Marime"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Scriere"; 
$LANG['device_drive'][1]="Viteza"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Cache"; 
$LANG['device_hdd'][4]="Capacitate"; 

$LANG['device_iface'][0]="Flux"; 
$LANG['device_iface'][2]="Adresa MAC"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Alimentare"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frecventa"; 
$LANG['device_ram'][2]="Marime"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Fisier"; 
$LANG['document'][3]="Antet"; 
$LANG['document'][4]="Tip MIME"; 
$LANG['document'][7]="Tipul documentului"; 
$LANG['document'][9]="Extensie"; 
$LANG['document'][10]="Icon"; 
$LANG['document'][11]="Download autorizat"; 
$LANG['document'][15]="Descarca"; 
$LANG['document'][16]="Adauga un document"; 
$LANG['document'][18]="Document"; 
$LANG['document'][19]="Elemente asociate"; 
$LANG['document'][21]="Documente asociate"; 
$LANG['document'][22]="Fisier curent"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Fisier sters cu succes"; 
$LANG['document'][25]="Nu s-a putut sterge fisierul"; 
$LANG['document'][26]="Fisierul este valid. Incarcarea a reusit."; 
$LANG['document'][27]="Atac potential la upload incarcare, Sau fisier prea mare. Mutarea fisierului temporal a esuat."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Nu s-a putut creea directorul"; 
$LANG['document'][30]="Verificați dacă aveți drepturile necesare"; 
$LANG['document'][31]="Directorul documentelor nu exista"; 
$LANG['document'][32]="Tip fisier neautorizat"; 
$LANG['document'][33]="Adresa de internet"; 
$LANG['document'][34]="Creeaza director"; 
$LANG['document'][35]="Directorul incarcat nu exista"; 
$LANG['document'][36]="Folositi un fisier FTP instalat"; 
$LANG['document'][37]="Nici un fisier disponibil"; 
$LANG['document'][38]="Fisierul nu a fost gasit"; 
$LANG['document'][39]="Document mutat cu succes"; 
$LANG['document'][40]="Mutarea fisierului esuata"; 
$LANG['document'][41]="Document copiat cu succes"; 
$LANG['document'][42]="Adaugat de"; 
$LANG['document'][43]="Fisier necunoscut"; 
$LANG['document'][44]="Nume de fișier eronat"; 
$LANG['document'][45]="Nu aveți acces la acest fișier"; 
$LANG['document'][46]="Trimiterea fisierului a esuat (prea mare)"; 
$LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
$LANG['document'][49]="Fișierul e incorect (checksum incorect)"; 
$LANG['document'][50]="Attached items"; 

$LANG['entity'][0]="Entitate"; 
$LANG['entity'][2]="Entitatea parinte"; 
$LANG['entity'][3]="Asociaza cu o entitate"; 
$LANG['entity'][5]="Automatic computer assignment"; 
$LANG['entity'][6]="Repartizare automata a utilizatorilor"; 
$LANG['entity'][7]="Structura de tip arbore"; 
$LANG['entity'][8]="După entitate"; 
$LANG['entity'][9]="Entitatea copil"; 
$LANG['entity'][10]="Selectati entitatea dorita"; 
$LANG['entity'][11]="pentru a vedea entitatea si diviziunile ei"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Advanced informations"; 
$LANG['entity'][15]="LDAP directory of an entity"; 
$LANG['entity'][16]="Search filter (if needed)"; 
$LANG['entity'][17]="Automatic closing configuration"; 
$LANG['entity'][18]="Automatic closing of the tickets after"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Service"; 
$LANG['event'][3]="Nivel"; 
$LANG['event'][4]="Mesaj"; 
$LANG['event'][18]="Camp"; 
$LANG['event'][19]="Actualizeaza"; 
$LANG['event'][20]="Fara istorie"; 

$LANG['financial'][1]="Contract"; 
$LANG['financial'][2]="Pe viață"; 
$LANG['financial'][3]="Informatii financiare"; 
$LANG['financial'][4]="Numar"; 
$LANG['financial'][5]="Cost"; 
$LANG['financial'][6]="Tipul contractului"; 
$LANG['financial'][8]="Durata"; 
$LANG['financial'][9]="an(i)"; 
$LANG['financial'][10]="Anunt"; 
$LANG['financial'][11]="Perioada facturare"; 
$LANG['financial'][13]="Numarul contului"; 
$LANG['financial'][14]="Data achizitiei"; 
$LANG['financial'][15]="Durata garanției"; 
$LANG['financial'][16]="Informatii garantie"; 
$LANG['financial'][18]="Numar de comanda"; 
$LANG['financial'][19]="Livrat de"; 
$LANG['financial'][20]="Numar de imobilizare"; 
$LANG['financial'][21]="Valoare"; 
$LANG['financial'][22]="Tip de amortizare"; 
$LANG['financial'][23]="Durata de amortizare"; 
$LANG['financial'][24]="Adauga contact..."; 
$LANG['financial'][25]="Adauga furnizor..."; 
$LANG['financial'][26]="Furnizor"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Adauga un contact"; 
$LANG['financial'][36]="Adauga un contract"; 
$LANG['financial'][42]="Commercial"; 
$LANG['financial'][43]="Tehnician"; 
$LANG['financial'][44]="Adresa"; 
$LANG['financial'][45]="Site internet"; 
$LANG['financial'][46]="Contacte asociate"; 
$LANG['financial'][47]="Liniar"; 
$LANG['financial'][48]="Descrescator"; 
$LANG['financial'][50]="Imprumut"; 
$LANG['financial'][51]="Inchiriere"; 
$LANG['financial'][52]="Leasing"; 
$LANG['financial'][53]="Asigurare"; 
$LANG['financial'][54]="Suport hardware"; 
$LANG['financial'][55]="Suport software"; 
$LANG['financial'][56]="Service furnizat"; 
$LANG['financial'][57]="luna"; 
$LANG['financial'][59]="Ore interventie"; 
$LANG['financial'][60]="pe saptamana"; 
$LANG['financial'][61]="Sambata"; 
$LANG['financial'][62]="Duminica si in zilele libere"; 
$LANG['financial'][65]="Furnizori asociati"; 
$LANG['financial'][66]="Contracte asociate"; 
$LANG['financial'][68]="Activeaza informatiile financiare"; 
$LANG['financial'][69]="Perioada contractului"; 
$LANG['financial'][76]="Data de pornire"; 
$LANG['financial'][77]="Coeficient de amortizare"; 
$LANG['financial'][78]="Valoarea de sfarsit a garantiei"; 
$LANG['financial'][79]="Tip de terti"; 
$LANG['financial'][80]="Data de sfarsit a garantiei"; 
$LANG['financial'][81]="Valoarea neta a contului"; 
$LANG['financial'][82]="Numar factura"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="Pentru acest tip de element informatia financiara este numai un model pentru elementele pe care le veti adauga."; 
$LANG['financial'][85]="Obiectul cautat nu a fost gasit"; 
$LANG['financial'][86]="End of contract"; 
$LANG['financial'][87]="Buget"; 
$LANG['financial'][88]="Activ pana la:"; 
$LANG['financial'][89]="TCO (valoare + costul de urmarire)"; 
$LANG['financial'][90]="TCO lunar"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Contracte expirate - ultimile 30 zile"; 
$LANG['financial'][94]="Contracte care expira in mai putin de 7 zile"; 
$LANG['financial'][95]="Contracte care expira in mai putin de 30 zile"; 
$LANG['financial'][96]="Contracte in care avizul incepe in mai putin de 7 zile"; 
$LANG['financial'][97]="Contracte in care avizul incepe in mai putin de 30 de zile"; 
$LANG['financial'][98]="Data expirarii"; 
$LANG['financial'][99]="Data expirarii + Notificare"; 
$LANG['financial'][100]="Cod postal"; 
$LANG['financial'][101]="Oras"; 
$LANG['financial'][102]="Stare"; 
$LANG['financial'][103]="Tara"; 
$LANG['financial'][104]="Elemente asociate"; 
$LANG['financial'][105]="Tacit"; 
$LANG['financial'][106]="Express"; 
$LANG['financial'][107]="Reinnoire"; 
$LANG['financial'][108]="Total spent on the budget"; 
$LANG['financial'][109]="Total remaining on the budget"; 
$LANG['financial'][110]="Budgets"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="ore"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrix of calculus for priority"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Foarte ridicata"; 
$LANG['help'][4]="Ridicata"; 
$LANG['help'][5]="Medie"; 
$LANG['help'][6]="Redusa"; 
$LANG['help'][7]="Foarte scazuta"; 
$LANG['help'][8]="Informeaza-ma despre actiunile de urmarire luate"; 
$LANG['help'][11]="E-mail-ul meu"; 
$LANG['help'][14]="Trimite mesajul"; 
$LANG['help'][16]="Dacă vreți să fiți înștiințat de acțiunile de urmărire luate, trebuie să vă introduceți adresa de e-mail."; 
$LANG['help'][18]="Problema a fost trimisa cu succes, fiind inregistrata in baza de date."; 
$LANG['help'][19]="Multumim ca ati folosit sistemul automat Helpdesk."; 
$LANG['help'][22]="Cautati ID-ul calculatorului dumneavastra"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Tip hardware"; 
$LANG['help'][25]="Calculator"; 
$LANG['help'][26]="Dispozitiv de retea"; 
$LANG['help'][27]="Imprimanta"; 
$LANG['help'][28]="Monitor"; 
$LANG['help'][29]="Dispozitiv"; 
$LANG['help'][30]="General"; 
$LANG['help'][31]="Software"; 
$LANG['help'][35]="Telefon"; 
$LANG['help'][40]="Problema nu are titlu, va rugam reincercati."; 
$LANG['help'][41]="Nu a fost gasita o categorie a problemei, va rugam reincercati."; 
$LANG['help'][42]="Very High"; 
$LANG['help'][43]="Ridicată"; 
$LANG['help'][44]="Medium"; 
$LANG['help'][45]="Scăzută"; 
$LANG['help'][46]="Very Low"; 
$LANG['help'][47]="Very High"; 
$LANG['help'][48]="Ridicat"; 
$LANG['help'][49]="Medium"; 
$LANG['help'][50]="Scăzut"; 
$LANG['help'][51]="Very Low"; 

$LANG['install'][0]="Instaleaza sau actualizeaza GLPI"; 
$LANG['install'][1]="Alegeți 'Instalare' pentru o instalare nouă a GLPI."; 
$LANG['install'][2]="Alegeți 'Actualizare' pentru o actualizare a GLPI de la o versiune mai veche"; 
$LANG['install'][3]="Instaleaza"; 
$LANG['install'][4]="Actualizeaza"; 
$LANG['install'][5]="Verificati compatibilitatea mediului cu rularea GLPI"; 
$LANG['install'][6]="S-a terminat testul"; 
$LANG['install'][7]="Rezultate"; 
$LANG['install'][8]="Testeaza parser-ul PHP"; 
$LANG['install'][9]="Trebuie să instalați cel puțin versiunea 5 a PHP."; 
$LANG['install'][10]="GLPI is not compatible with the option zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="Versiunea PHP este mai mare decât minimum necesar – Perfect!"; 
$LANG['install'][12]="Test sesiune"; 
$LANG['install'][13]="Parser-ul PHP nu a fost compilat cu sesiuni de ajutor !"; 
$LANG['install'][14]="Suportul pentru sesiuni este disponibil – Perfect!"; 
$LANG['install'][15]="Verificati daca suportul pentru sesiuni este activat in php.ini"; 
$LANG['install'][16]="Verificati modul de scriere pentru fisierele de export"; 
$LANG['install'][17]="Fisierul nu a putut fi creat."; 
$LANG['install'][18]="Unofficial translations are also available"; 
$LANG['install'][19]="fisierul a fost creat dar nu poate fi sters."; 
$LANG['install'][20]="Un fișier și un director au fost create și șterse – Perfect!"; 
$LANG['install'][21]="Verificati modul de scriere pentru fisierele document"; 
$LANG['install'][22]="A file was created - Perfect !"; 
$LANG['install'][23]="Verificati modul de scriere pentru fisierele de setare"; 
$LANG['install'][24]="Initialization of the database"; 
$LANG['install'][25]="Continuati ?"; 
$LANG['install'][26]="Continuati"; 
$LANG['install'][27]="Reincearcati"; 
$LANG['install'][28]="Initiere conexiune cu baza de date"; 
$LANG['install'][29]="Parametrii de conectare la baza de date"; 
$LANG['install'][30]="Server Mysql"; 
$LANG['install'][31]="Nume utilizator Mysql"; 
$LANG['install'][32]="Parola MySQL"; 
$LANG['install'][34]="Testarea conexiunii la baza de date"; 
$LANG['install'][35]="Imposibil de conectat la baza de date"; 
$LANG['install'][36]="Serverul a rspuns"; 
$LANG['install'][37]="Câmpurile „server Mysql“ și/sau „nume utilizator Mysql“ sunt goale"; 
$LANG['install'][38]="Selectati o baza de date:"; 
$LANG['install'][39]="Creati o noua baza de date sau folositi una existenta:"; 
$LANG['install'][40]="Selectati o baza de date pentru actualizare:"; 
$LANG['install'][41]="Imposibil de utilizat baza de date:"; 
$LANG['install'][43]="OK - baza de date a fost initializata"; 
$LANG['install'][47]="Imposibil de scris fisierul de setup al bazei de date"; 
$LANG['install'][48]="Eroare in crearea bazei de date !"; 
$LANG['install'][49]="Nu ati selectat nici o baza de date !"; 
$LANG['install'][50]="Verificarea permisiunilor de scriere a fisierelor pentru sesiune"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="Test de scriere a fișierelor de logare"; 
$LANG['install'][55]="Instalarea a fost efectuata"; 
$LANG['install'][57]="Numele utilizator si parola implicite sunt:"; 
$LANG['install'][58]="glpi/glpi pentru contul de administrator"; 
$LANG['install'][59]="tech/tech pentru contul technicianului"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="Folositi GLPI"; 
$LANG['install'][65]="testarea extensiei magic_quotes_sybase"; 
$LANG['install'][66]="GLPI nu lucreaza cu optiunea magic_quotes_sybase; Dezactivati optiunea si reincercati"; 
$LANG['install'][67]="Opțiunea magic_quotes_sybase nu este activă pe server – Perfect!"; 
$LANG['install'][68]="Test session auto start"; 
$LANG['install'][69]="session.auto_start is activated. See .htaccess file in the GLPI root for more information."; 
$LANG['install'][70]="Imposibil de creat fisierul de conectare la baza de date, verificati drepturile asupra fisierelor"; 
$LANG['install'][71]="testarea extensiei MySQL."; 
$LANG['install'][72]="Trebuie sa compilati PHP-ul cu extensia MySQL."; 
$LANG['install'][73]="OK - funcția mysql_query() există – Perfect!"; 
$LANG['install'][74]="Testeaza daca Session_use_trans_sid este folosit"; 
$LANG['install'][75]="Trebuie sa dezactivati optiunea Session_use_trans_id din php.ini"; 
$LANG['install'][76]="OK - sesiunea funcționează (nici o problemă cu trans_id) – Perfect!"; 
$LANG['install'][77]="Pas"; 
$LANG['install'][81]="Inceputul instalarii"; 
$LANG['install'][82]="Baza de date creata"; 
$LANG['install'][85]="Funcțiile au fost găsite – Perfect !"; 
$LANG['install'][86]="Test memorie alocata"; 
$LANG['install'][87]="Memorie alocata:"; 
$LANG['install'][88]="Un minim de 64MB este necesar pentru GLPI."; 
$LANG['install'][89]="Perfect!"; 
$LANG['install'][90]="Incercati sa mariti parametrul memory_limit  in php.ini"; 
$LANG['install'][91]="Memorie alocata >64M"; 
$LANG['install'][92]="Licenta"; 
$LANG['install'][93]="Am citit si ACCEPT termenii din licenta de mai sus."; 
$LANG['install'][94]="Am citit si NU ACCEPT termenii de licenta de mai jos"; 
$LANG['install'][95]="Memorie nelimitata"; 
$LANG['install'][96]="Memorie nelimitata"; 
$LANG['install'][97]="Verificați drepturile pe director:"; 
$LANG['install'][99]="Se verifica permisiunea de a scrie pentru fisierele Cache"; 
$LANG['install'][100]="Directorul nu a putut fi creat."; 
$LANG['install'][101]="Directorul a fost creat, dar nu a putut fi indepartat"; 
$LANG['install'][102]="Test json functions"; 
$LANG['install'][103]="GLPI can't work correctly without the json_encode and json_decode functions"; 
$LANG['install'][104]="mbstring extension test"; 
$LANG['install'][105]="Mbstring extension of your parser PHP is not installed"; 
$LANG['install'][106]="Checking write permissions for graphic files"; 

$LANG['job'][2]="după"; 
$LANG['job'][4]="Solicitant"; 
$LANG['job'][5]="Repartizat catre"; 
$LANG['job'][6]="Tehnician"; 
$LANG['job'][7]="Task"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Follow-up"; 
$LANG['job'][11]="Descriere a problemei/acțiunii"; 
$LANG['job'][12]="Nu exista nici o comentariu/solutie pentru aceasta problema."; 
$LANG['job'][13]="Adaugă o nouă problemă"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Comentarii pe E-mail"; 
$LANG['job'][20]="Timp total"; 
$LANG['job'][21]="Ora/e"; 
$LANG['job'][22]="Minut(e)"; 
$LANG['job'][29]="Adauga comentariu/rezolvare"; 
$LANG['job'][30]="Add a new task"; 
$LANG['job'][31]="Durata"; 
$LANG['job'][32]="Nimic"; 
$LANG['job'][33]="Lipsa descriere"; 
$LANG['job'][34]="Planifică această sarcină"; 
$LANG['job'][35]="Planificare"; 
$LANG['job'][37]="Rezumat"; 
$LANG['job'][38]="Problema nr:"; 
$LANG['job'][39]="Actualizeaza comentariile"; 
$LANG['job'][40]="Manopera"; 
$LANG['job'][41]="Cost fix"; 
$LANG['job'][42]="Costul materialelor"; 
$LANG['job'][43]="Costul total"; 
$LANG['job'][44]="Solicita sursa"; 
$LANG['job'][45]="Source of follow-up"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Type of solution"; 
$LANG['job'][49]="New task"; 
$LANG['job'][50]="No task for this ticket"; 
$LANG['job'][51]="Approval of the solution"; 
$LANG['job'][52]="Update task"; 
$LANG['job'][53]="Deletion of a task"; 
$LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 

$LANG['joblist'][0]="Starea problemelor"; 
$LANG['joblist'][1]="Doar in ale mele"; 
$LANG['joblist'][2]="Prioritate"; 
$LANG['joblist'][3]="Ale mele și ale grupurilor"; 
$LANG['joblist'][4]="Repartizat"; 
$LANG['joblist'][6]="Descriere"; 
$LANG['joblist'][7]="O noua problema pentru acest obiect..."; 
$LANG['joblist'][8]="Nu a fost gasita nici o problema"; 
$LANG['joblist'][9]="Noi"; 
$LANG['joblist'][10]="Inchise (Rezolvate)"; 
$LANG['joblist'][11]="Deschis"; 
$LANG['joblist'][12]="Închis"; 
$LANG['joblist'][13]="Tickets to be processed"; 
$LANG['joblist'][14]="Solved on"; 
$LANG['joblist'][16]="Nu sunt probleme în curs de rezolvare."; 
$LANG['joblist'][17]="Inchise (Nerezolvate)"; 
$LANG['joblist'][18]="In curs de repartizare"; 
$LANG['joblist'][19]="In curs de planificare"; 
$LANG['joblist'][21]="In curs de procesare"; 
$LANG['joblist'][26]="In asteptare"; 
$LANG['joblist'][27]="E-mail-ul pentru comentarii"; 
$LANG['joblist'][28]="Tickets on linked items"; 
$LANG['joblist'][29]="Urgency"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Solved"; 
$LANG['joblist'][33]="Closed"; 
$LANG['joblist'][34]="Not solved"; 
$LANG['joblist'][35]="Not closed"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Solution"; 
$LANG['jobresolution'][3]="Approved solution"; 
$LANG['jobresolution'][4]="Refused solution"; 
$LANG['jobresolution'][5]="If you reject the solution, you must specify a reason"; 

$LANG['knowbase'][1]="Intrebari frecvente"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Selectati o categorie pentru acest obiect :"; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="Modifica acest obiect"; 
$LANG['knowbase'][9]="Sterge aceast obiect"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Radacina"; 
$LANG['knowbase'][13]="Numele categoriei"; 
$LANG['knowbase'][14]="Subiect"; 
$LANG['knowbase'][15]="Cuprins"; 
$LANG['knowbase'][24]="Acces la intrebarile cele mai frecvente"; 
$LANG['knowbase'][26]="Vizualizare"; 
$LANG['knowbase'][27]="Pornit"; 
$LANG['knowbase'][29]="Intrari recente"; 
$LANG['knowbase'][30]="Cele mai frecvente intrebari"; 

$LANG['ldap'][0]="Bulk import users from a LDAP directory"; 
$LANG['ldap'][1]="Sincronizarea utilizatorilor deja importati"; 
$LANG['ldap'][2]="Importa utilizatori noi"; 
$LANG['ldap'][3]="Nici un utilizator pentru import"; 
$LANG['ldap'][4]="Alegeti directorul LDAP"; 
$LANG['ldap'][5]="Selectati directorul LDAP de unde sa importati utilizatorii"; 
$LANG['ldap'][6]="Conexiune imposibila cu directorul LDAP"; 
$LANG['ldap'][7]="Nici un director LDAP definit in GLPI"; 
$LANG['ldap'][8]="Warning: The request exceeds the limit of the directory. The results are only partial."; 
$LANG['ldap'][9]="Testarea conexiunii cu directorul LDAP"; 
$LANG['ldap'][12]="Sincronizare"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="in GLPI"; 
$LANG['ldap'][15]="Sincronizati"; 
$LANG['ldap'][16]="Preconfigurare"; 
$LANG['ldap'][17]="Director activ"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Copie"; 
$LANG['ldap'][20]="Add a LDAP directory replica"; 
$LANG['ldap'][21]="Server principal"; 
$LANG['ldap'][22]="Copie"; 
$LANG['ldap'][23]="Bulk import groups from a LDAP directory"; 
$LANG['ldap'][24]="Importa grupuri noi"; 
$LANG['ldap'][25]="Nici un grup pentru import"; 
$LANG['ldap'][30]="Cum ar trebui utilizate aliasurile LDAP"; 
$LANG['ldap'][31]="Niciodata dereferentiat (implicit)"; 
$LANG['ldap'][32]="Intotdeauna dereferentiat"; 
$LANG['ldap'][33]="Dereferentiere in timpul cautarii (dar nu si la gasire)"; 
$LANG['ldap'][34]="Dereferentiere la gasire (dar nu si in tipul cautarii)"; 
$LANG['ldap'][35]="Import an user"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Search criterias for users"; 
$LANG['ldap'][39]="Advanced"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="To change"; 
$LANG['ldap'][42]="No directory selected"; 
$LANG['ldap'][43]="No users to be synchronized"; 
$LANG['ldap'][44]="Default server"; 
$LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Deleted user in LDAP directory"; 
$LANG['ldap'][49]="View users added since"; 
$LANG['ldap'][50]="View users updated since"; 
$LANG['ldap'][52]="Less than"; 
$LANG['ldap'][53]="More than"; 
$LANG['ldap'][54]="Enable filtering by date"; 
$LANG['ldap'][55]="Disable filtering by date"; 
$LANG['ldap'][56]="Weeks"; 

$LANG['links'][1]="Link sau nume de fisier"; 
$LANG['links'][4]="Tipul hardware-ului asociat"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="Nici un link definit"; 
$LANG['links'][9]="Continutul fisierului"; 

$LANG['log'][1]="sistem"; 
$LANG['log'][16]="planificari"; 
$LANG['log'][18]="componente"; 
$LANG['log'][20]="obiect adaugat"; 
$LANG['log'][21]="actualizeaza obiect"; 
$LANG['log'][22]="sterge un obiect"; 
$LANG['log'][23]="repara obiect"; 
$LANG['log'][24]="curata obiectul"; 
$LANG['log'][26]="deconecteaza obiect"; 
$LANG['log'][27]="conexiune obiect"; 
$LANG['log'][28]="modificarea componentelor"; 
$LANG['log'][29]="approval/refusal of the solution"; 
$LANG['log'][30]="asociaza un tip"; 
$LANG['log'][31]="sterge un tip"; 
$LANG['log'][32]="adaugă un link cu obiect"; 
$LANG['log'][33]="sterge link-ul cu obiect"; 
$LANG['log'][34]="adauga un link cu furnizor"; 
$LANG['log'][35]="sterge link-ul cu furnizor"; 
$LANG['log'][40]="Conexiune Ip"; 
$LANG['log'][41]="conexiune esuata"; 
$LANG['log'][42]="Rezervare"; 
$LANG['log'][44]="Rubrica"; 
$LANG['log'][45]="Realizat"; 
$LANG['log'][46]="Esuat"; 
$LANG['log'][48]="adauga utilizator grupului"; 
$LANG['log'][49]="sterge utilizator din grup"; 
$LANG['log'][55]="Conexiune"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="adauga utilizator entitatii"; 
$LANG['log'][62]="sterge complet acest utilizator"; 
$LANG['log'][64]="modification of field"; 
$LANG['log'][65]="regula"; 
$LANG['log'][66]="Securitate"; 
$LANG['log'][67]="modificarea notelor"; 
$LANG['log'][70]="adaugare port de retea"; 
$LANG['log'][71]="adaugarea mai multor porturi de retea"; 
$LANG['log'][73]="stergere port de retea"; 
$LANG['log'][74]="stergerea mai multor porturi de retea"; 
$LANG['log'][75]="mutare port de retea"; 
$LANG['log'][77]="associate a VLAN to a network port"; 
$LANG['log'][78]="associate a VLAN to several ports"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="dissociation of a VLAN from multiple network ports"; 
$LANG['log'][82]="adauga versiune"; 
$LANG['log'][83]="modificarea versiunii"; 
$LANG['log'][84]="Versiune suprimata"; 
$LANG['log'][85]="adauga licenta"; 
$LANG['log'][86]="modificarea licentei"; 
$LANG['log'][87]="Expirarea licentei"; 
$LANG['log'][88]="adding cartridges"; 
$LANG['log'][89]="adding consumables"; 
$LANG['log'][90]="deletion of a cartridge"; 
$LANG['log'][91]="deletion of a consumable"; 
$LANG['log'][92]="restoration of a cartridge"; 
$LANG['log'][93]="restoration of a consumable"; 
$LANG['log'][94]="cartridge's update"; 
$LANG['log'][95]="cartridge's installation"; 
$LANG['log'][96]="cartridge's uninstallation"; 
$LANG['log'][97]="consumable out for the user"; 
$LANG['log'][98]="add an element"; 
$LANG['log'][99]="modification of an item"; 
$LANG['log'][100]="deletion of an item"; 

$LANG['login'][0]="Ultima autentificare"; 
$LANG['login'][1]="Autentificati-va din nou"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Acces interzis"; 
$LANG['login'][6]="Utilizator"; 
$LANG['login'][7]="Parola"; 
$LANG['login'][8]="Nume utilizator sau parola goale"; 
$LANG['login'][9]="Nu ati fost inca autentificat"; 
$LANG['login'][10]="Autentificare"; 
$LANG['login'][11]="Utilizator neautorizat pentru conectare la GLPI"; 
$LANG['login'][12]="Nume utilizator sau parola incorecte"; 
$LANG['login'][13]="Capmpul cu parola este gol"; 
$LANG['login'][14]="utilizator necunoscut"; 
$LANG['login'][15]="Numele utilizatorul nu a fost gasit sau au fost gasiti mai multi utilizatori cu nume identic"; 
$LANG['login'][16]="autorizarea in LDAP nereusita"; 
$LANG['login'][18]="Baza GLPI interna"; 
$LANG['login'][20]="Nu aveți acces la această aplicație deoarece contul dumneavoastră a fost dezactivat sau șters"; 
$LANG['login'][21]="Test de conectare la server-ul IMAP/POP"; 
$LANG['login'][22]="Testul a fost realizat cu succes"; 
$LANG['login'][23]="Test esuat"; 
$LANG['login'][24]="Data ultimei logari"; 
$LANG['login'][25]="Nu aveți drepturi de conectare la această aplicație"; 
$LANG['login'][26]="Trebuie sa activati functia JavaScript"; 
$LANG['login'][27]="Trebuie să acceptați cookie-uri pentru a avea acces la această aplicație"; 
$LANG['login'][30]="Schimba metoda de autentificare"; 
$LANG['login'][31]="Authentication on a LDAP directory"; 
$LANG['login'][32]="Autentificare in baza de date GLPI"; 
$LANG['login'][33]="Autentificare pe serverul IMAP/POP"; 

$LANG['mailgate'][0]="Gateway pentru E-mail"; 
$LANG['mailgate'][2]="Obtine problemele de E-mail"; 
$LANG['mailgate'][3]="Numar de E-mail-uri disponibile si regasite"; 
$LANG['mailgate'][4]="extensia mbstring nu a fost gasita. Atentie la charsets-urile utilizate."; 
$LANG['mailgate'][5]="Fisierul atasat este defect"; 
$LANG['mailgate'][6]="Fisierul atasat este prea mare"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Your email could not be processed.\nIf the problem persists, contact the administrator"; 
$LANG['mailgate'][10]="Email refused"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email not found. Impossible import"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Comentarii deja efectuate"; 
$LANG['mailing'][5]="Descrierea problemei"; 
$LANG['mailing'][10]="Comentarii noi la probleme"; 
$LANG['mailing'][12]="Problema atribuita catre"; 
$LANG['mailing'][14]="Actualizeaza felul problemei"; 
$LANG['mailing'][15]="Actualizeaza prioritatea problemei"; 
$LANG['mailing'][17]="Actualizeaza problema obiectul"; 
$LANG['mailing'][18]="Actualizeaza autorul problemei"; 
$LANG['mailing'][19]="Rezervare noua"; 
$LANG['mailing'][20]="Actualizeaza grupa de probleme"; 
$LANG['mailing'][21]="Schimbari la sursa problemei"; 
$LANG['mailing'][23]="Modificarea rezervarii"; 
$LANG['mailing'][26]="Document adaugat :"; 
$LANG['mailing'][27]="Actualizeaza starea problemei"; 
$LANG['mailing'][29]="Rezervare anulata"; 
$LANG['mailing'][30]="Actualizeaza lista cu probleme"; 
$LANG['mailing'][31]="Acesta este un E-mail test pentru a verifica daca sistemul functioneaza"; 
$LANG['mailing'][32]="Trimite E-mail test"; 
$LANG['mailing'][33]="Alarma cartuse"; 
$LANG['mailing'][35]="Nivelul de alarma atins pentru tipul de consumabil:"; 
$LANG['mailing'][36]="Alarma consumabile"; 
$LANG['mailing'][37]="Contract intrat in tip util:"; 
$LANG['mailing'][39]="Alarma contracte"; 
$LANG['mailing'][40]="Element ajuns la sfarsitul garantiei :"; 
$LANG['mailing'][41]="Alarma informatii financiare"; 
$LANG['mailing'][42]="Schimbari la manopera"; 
$LANG['mailing'][43]="Schimbari la costurile fixe"; 
$LANG['mailing'][44]="Schimbari la costurile materialelor"; 
$LANG['mailing'][45]="Schimba titlul problemei"; 
$LANG['mailing'][46]="Schimbari in descrierea problemei"; 
$LANG['mailing'][47]="Eroare in trimiterea E-mail-ului"; 
$LANG['mailing'][48]="Schimbari la datele de deschidere"; 
$LANG['mailing'][49]="Schimbari la datele de inchidere"; 
$LANG['mailing'][50]="Schimba destinatarul problemei"; 
$LANG['mailing'][51]="Licenta expirata :"; 
$LANG['mailing'][53]="Change of solution"; 
$LANG['mailing'][54]="Expiry date"; 
$LANG['mailing'][100]="Nici o categorie declarata"; 
$LANG['mailing'][101]="Comentariile pe E-mail au fost activate"; 
$LANG['mailing'][102]="Comentariile pe E-mail au fost dezactivate"; 
$LANG['mailing'][104]="Durata unui comentariu"; 
$LANG['mailing'][105]="Nu este atribuit"; 
$LANG['mailing'][107]="Nimic"; 
$LANG['mailing'][109]="Fara grup"; 
$LANG['mailing'][110]="E-mail eronat"; 
$LANG['mailing'][113]="Notification templates"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="E-mail"; 
$LANG['mailing'][119]="Occurrence"; 
$LANG['mailing'][120]="Notification method"; 
$LANG['mailing'][121]="Recipients"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Solved ticket"; 
$LANG['mailing'][124]="Add a new translation"; 
$LANG['mailing'][125]="Default translation"; 
$LANG['mailing'][126]="Template translation"; 
$LANG['mailing'][127]="Closing of the ticket"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Deletion of a ticket"; 
$LANG['mailing'][130]="From"; 
$LANG['mailing'][131]="Recipient"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Delete email(s)"; 
$LANG['mailing'][134]="Updating follow-up"; 
$LANG['mailing'][135]="Follow-up's deletion"; 
$LANG['mailing'][136]="Reservation expired"; 
$LANG['mailing'][137]="Hardware user"; 
$LANG['mailing'][138]="List of available tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Followups"; 
$LANG['mailing'][142]="Tasks"; 
$LANG['mailing'][143]="Validations"; 
$LANG['mailing'][144]="Historical"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Single value"; 
$LANG['mailing'][147]="Possible value(s)"; 

$LANG['Menu'][0]="Calculatoare"; 
$LANG['Menu'][1]="Retele"; 
$LANG['Menu'][2]="Imprimante"; 
$LANG['Menu'][3]="Monitoare"; 
$LANG['Menu'][4]="Software"; 
$LANG['Menu'][5]="probleme"; 
$LANG['Menu'][6]="Rapoarte"; 
$LANG['Menu'][11]="Setari"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="Statistici"; 
$LANG['Menu'][14]="Utilizatori"; 
$LANG['Menu'][15]="Administrare"; 
$LANG['Menu'][16]="Dispozitive"; 
$LANG['Menu'][17]="Rezervari"; 
$LANG['Menu'][18]="Unelte"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="Intrebari frecvente"; 
$LANG['Menu'][21]="Cartuse"; 
$LANG['Menu'][22]="Contacte"; 
$LANG['Menu'][23]="Furnizori"; 
$LANG['Menu'][24]="Informatii financiare"; 
$LANG['Menu'][25]="Contracte"; 
$LANG['Menu'][26]="Management"; 
$LANG['Menu'][27]="Documente"; 
$LANG['Menu'][28]="Status"; 
$LANG['Menu'][29]="Planificari"; 
$LANG['Menu'][30]="Logari"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Consumabile"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefoane"; 
$LANG['Menu'][35]="Profiluri"; 
$LANG['Menu'][36]="Grupuri"; 
$LANG['Menu'][37]="Entitati"; 
$LANG['Menu'][38]="Inventar"; 
$LANG['Menu'][39]="Gateway pentru E-mail"; 
$LANG['Menu'][40]="Semne de carte"; 
$LANG['Menu'][41]="Drepturile"; 

$LANG['monitors'][14]="Microfon"; 
$LANG['monitors'][15]="Difuzoare"; 
$LANG['monitors'][18]="Indicatori"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Marime"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot"; 

$LANG['networking'][4]="Network port"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Port de retea"; 
$LANG['networking'][13]="porturi de retea gasite"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Conectat la"; 
$LANG['networking'][19]="Adauga port retea..."; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="pornit"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="Portul"; 
$LANG['networking'][46]="Adauga porturi..."; 
$LANG['networking'][47]="De la"; 
$LANG['networking'][48]="Catre"; 
$LANG['networking'][51]="Nod de retea"; 
$LANG['networking'][55]="Asociaza un VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Alege o adresa MAC din lista sau specifica una mai jos"; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Masca"; 
$LANG['networking'][61]="Subretea"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Optiuni de importare"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Excludeti urmatoarele tag-uri (separator $, nimic pentru toate)"; 
$LANG['ocsconfig'][10]="Import global"; 
$LANG['ocsconfig'][11]="Nici un import"; 
$LANG['ocsconfig'][12]="Unitatea de import"; 
$LANG['ocsconfig'][13]="Import de unitate: totul este importat 'ca - este'"; 
$LANG['ocsconfig'][14]="Import global: totul este importat, dar materialul este gestionat la nivel global (fara dublu blooms)"; 
$LANG['ocsconfig'][15]="Fara import: plugin-ul nu va importa aceste elemente"; 
$LANG['ocsconfig'][16]="Status implicit"; 
$LANG['ocsconfig'][17]="Limita de import pentru urmatoarele tag-uri ($ separator, nimic pentru toate)"; 
$LANG['ocsconfig'][18]="Mai intai, verificati ca dublurile sunt gestionate in OCSNG"; 
$LANG['ocsconfig'][19]="Import de unitate pe numarul de serie"; 
$LANG['ocsconfig'][27]="Informatii generale"; 
$LANG['ocsconfig'][36]="Modemuri"; 
$LANG['ocsconfig'][37]="Porturi"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Registru"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="Comportamentul atunci când deconectati"; 
$LANG['ocsconfig'][49]="Cos de gunoi"; 
$LANG['ocsconfig'][50]="Stergere"; 
$LANG['ocsconfig'][52]="Automatic connection of computers"; 
$LANG['ocsconfig'][53]="Enable the automatic link"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="gol"; 
$LANG['ocsconfig'][57]="egal"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="OCS Inventarul NG"; 
$LANG['ocsng'][1]="Sincronizeaza computerele deja importate"; 
$LANG['ocsng'][2]="Importa noi computere"; 
$LANG['ocsng'][3]="Clean links between GLPI and OCSNG"; 
$LANG['ocsng'][4]="Asociaza noile computere OCS cu computerele GLPI existente"; 
$LANG['ocsng'][5]="Importa noi computere"; 
$LANG['ocsng'][6]="Actualizare automata"; 
$LANG['ocsng'][7]="Importat din OCSNG"; 
$LANG['ocsng'][8]="Importul s-a realizat cu succes"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="actualizeaza computerele"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="Importa data in GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="Nici un camp blocat"; 
$LANG['ocsng'][16]="Campuri blocate"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="Atentie! Datele importate (vezi configurarea) vor suprascrie datele deja existente"; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Forteaza sincronizarea"; 
$LANG['ocsng'][26]="Choice of an OCSNG server"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Monitor blocat"; 
$LANG['ocsng'][32]="Dispozitiv blocat"; 
$LANG['ocsng'][34]="Imprimanta blocata"; 
$LANG['ocsng'][36]="Entitatea destinatiei"; 
$LANG['ocsng'][37]="Activeaza previzualizarea"; 
$LANG['ocsng'][38]="Dezactiveaza previzualizarea"; 
$LANG['ocsng'][40]="Se potrivește regula?"; 
$LANG['ocsng'][41]="Modul de import manual"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="Access denied on OCSNG database (Need write rights on hardware.CHECKSUM necessary)"; 
$LANG['ocsng'][44]="Access denied on OCSNG database (Delete rights in deleted_equiv table necessary)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Deleted in OCSNG"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="IP blocat"; 
$LANG['ocsng'][52]="Software blocat"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Volume(s) locked(s)"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="pana la"; 
$LANG['pager'][2]="de la"; 
$LANG['pager'][3]="din"; 
$LANG['pager'][4]="Afiseaza"; 
$LANG['pager'][5]="randuri"; 

$LANG['peripherals'][18]="Firma"; 
$LANG['peripherals'][31]="Management global"; 
$LANG['peripherals'][32]="Management unitate"; 
$LANG['peripherals'][33]="Tip de management"; 

$LANG['phones'][18]="Marca"; 
$LANG['phones'][36]="Alimentare"; 
$LANG['phones'][38]="Casti"; 
$LANG['phones'][39]="Difuzor"; 
$LANG['phones'][40]="Numarul de linii"; 

$LANG['planning'][0]="Tehnicianul solicitat are deja planificata o interventie"; 
$LANG['planning'][1]="Eroare la introducerea datelor. Data de inceput este mai mare decat data finala"; 
$LANG['planning'][5]="Zi"; 
$LANG['planning'][6]="Saptamana"; 
$LANG['planning'][8]="Urmarire"; 
$LANG['planning'][9]="După"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="Webcal:// Sincronizare"; 
$LANG['planning'][14]="Luna"; 
$LANG['planning'][15]="Planificarea personala"; 
$LANG['planning'][16]="Informatie"; 
$LANG['planning'][17]="De realizat"; 
$LANG['planning'][18]="Realizat"; 

$LANG['plugins'][0]="Plugins list"; 
$LANG['plugins'][2]="Installed / not configured"; 
$LANG['plugins'][3]="Installed / not activated"; 
$LANG['plugins'][4]="Error / to clean"; 
$LANG['plugins'][5]="Non-existent function(s)"; 
$LANG['plugins'][6]="To update"; 
$LANG['plugins'][7]="No plugin installed"; 
$LANG['plugins'][8]="See the catalog of plugins"; 
$LANG['plugins'][9]="Authors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Serial"; 
$LANG['printers'][15]="Paralela"; 
$LANG['printers'][18]="Porturi"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Initial page counter"; 
$LANG['printers'][31]="Pagini printate"; 

$LANG['profiles'][0]="Drept global"; 
$LANG['profiles'][1]="Drept pentru entitate"; 
$LANG['profiles'][2]="Interfața asociată la profil"; 
$LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
$LANG['profiles'][5]="Semnaleaza o problema"; 
$LANG['profiles'][6]="Adaugă o rezolvare la problema (autor)"; 
$LANG['profiles'][7]="Afiseaza toate problemele"; 
$LANG['profiles'][8]="Afișează toate comentariile și sarcinile (publice și private)"; 
$LANG['profiles'][9]="Afișează comentariile și sarcinile publice"; 
$LANG['profiles'][10]="Citeste"; 
$LANG['profiles'][11]="Scrie"; 
$LANG['profiles'][12]="Acces interzis"; 
$LANG['profiles'][13]="Profil implicit"; 
$LANG['profiles'][14]="Sterge o problema"; 
$LANG['profiles'][15]="Adauga comentarii tuturor problemelor"; 
$LANG['profiles'][16]="Responsabil pe o anumita problema"; 
$LANG['profiles'][17]="Imprumuta o problema"; 
$LANG['profiles'][18]="Actualizeaza o problema"; 
$LANG['profiles'][19]="Repartizeaza o problema"; 
$LANG['profiles'][20]="Vezi planning personal"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Profile"; 
$LANG['profiles'][23]="Administrarea rezervarilor"; 
$LANG['profiles'][24]="Actualizeaza parola"; 
$LANG['profiles'][26]="Arata poblemele create de catre grup"; 
$LANG['profiles'][27]="Vezi hardware-urile grupului"; 
$LANG['profiles'][28]="Recursiv"; 
$LANG['profiles'][29]="Dinamic"; 
$LANG['profiles'][30]="Vizualizeaza informatia OCSNG"; 
$LANG['profiles'][31]="Sincronizeaza OCSNG manual"; 
$LANG['profiles'][32]="Vezi problemele desemnate (personal + legate de grup)"; 
$LANG['profiles'][33]="Nu s-a gasit nici un utilizator"; 
$LANG['profiles'][34]="Legenda"; 
$LANG['profiles'][35]="Actualizeaza toate comentariile"; 
$LANG['profiles'][36]="Vezi programul persoanelor din grup"; 
$LANG['profiles'][37]="Entitate implicita"; 
$LANG['profiles'][38]="Vizibilitate"; 
$LANG['profiles'][39]="Repartizare"; 
$LANG['profiles'][40]="Actualizare"; 
$LANG['profiles'][41]="Creare"; 
$LANG['profiles'][42]="Asociere"; 
$LANG['profiles'][43]="Autentifica si sincronizeaza metoda utilizatorului"; 
$LANG['profiles'][44]="Change the priority"; 
$LANG['profiles'][45]="Add a task to all tickets"; 
$LANG['profiles'][46]="Edit all tasks"; 
$LANG['profiles'][47]="Add users from an external source"; 
$LANG['profiles'][48]="Create a validation request"; 
$LANG['profiles'][49]="Validate a ticket"; 

$LANG['registry'][1]="Hive"; 
$LANG['registry'][2]="Cale"; 
$LANG['registry'][3]="Cheie / valoare"; 
$LANG['registry'][4]="Cheia de inregistrare gasita"; 
$LANG['registry'][5]="Nu a fost gasita nici o cheie in registru"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Note personale"; 
$LANG['reminder'][1]="Note publice"; 
$LANG['reminder'][6]="Nota noua"; 
$LANG['reminder'][9]="Text"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="Fara titlu"; 
$LANG['reminder'][16]="Note globale"; 

$LANG['reports'][0]="Selectati un raport pe care doriti sa il generati"; 
$LANG['reports'][4]="Lista de hardware sub contract"; 
$LANG['reports'][11]="Hardware sub contract"; 
$LANG['reports'][12]="Tip hardware"; 
$LANG['reports'][13]="Data(e)"; 
$LANG['reports'][15]="Arata raport"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="Raport implicit"; 
$LANG['reports'][27]="După contract"; 
$LANG['reports'][28]="După an"; 
$LANG['reports'][33]="Raport retea"; 
$LANG['reports'][36]="Dispozitive conectate"; 
$LANG['reports'][37]="Drops"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="După locație"; 
$LANG['reports'][41]="După hardware"; 
$LANG['reports'][42]="După drop"; 
$LANG['reports'][46]="porturi hardware"; 
$LANG['reports'][47]="porturi dispozitive"; 
$LANG['reports'][49]="Raport rețea după hardware"; 
$LANG['reports'][51]="Network report by drop"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Raport retea dupa locatie"; 
$LANG['reports'][57]="Lista materiale"; 
$LANG['reports'][58]="Raport de hardware pe an"; 
$LANG['reports'][60]="Data deschiderii"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Informații financiare despre hardware"; 
$LANG['reports'][63]="Alte informatii financiare (licente, cartuse, consumabile)"; 
$LANG['reports'][64]="Resolution date"; 

$LANG['reservation'][1]="Element de rezervat"; 
$LANG['reservation'][2]="Dispozitiv temporar inaccesibil"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="Rezervare"; 
$LANG['reservation'][9]="Rezerva un obiect"; 
$LANG['reservation'][16]="Catre"; 
$LANG['reservation'][17]="De la"; 
$LANG['reservation'][18]="The required item is already reserved for this timeframe"; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Modifica comentariu"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Perioada"; 
$LANG['reservation'][28]="După săptăm&acirc;nă"; 
$LANG['reservation'][29]="In fiecare zi"; 
$LANG['reservation'][30]="timp"; 
$LANG['reservation'][31]="După"; 
$LANG['reservation'][35]="Rezervari viitoare si in curs de realizare"; 
$LANG['reservation'][36]="Rezervari anterioare"; 
$LANG['reservation'][37]="Nici o rezervare"; 
$LANG['reservation'][38]="Sigur doriți ca acest element nu mai poate fi împrumutat?"; 
$LANG['reservation'][39]="Această comandă va elimina toate rezervările în curs de desfășurare."; 
$LANG['reservation'][40]="Material reservations expiring today"; 

$LANG['rulesengine'][0]="Exista"; 
$LANG['rulesengine'][1]="Inexistent"; 
$LANG['rulesengine'][2]="contine"; 
$LANG['rulesengine'][3]="nu contine"; 
$LANG['rulesengine'][4]="Incepand cu"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Criteriu"; 
$LANG['rulesengine'][7]="Actiuni"; 
$LANG['rulesengine'][8]="Administreaza reguli"; 
$LANG['rulesengine'][9]="Operator logic"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Tipul actiunii"; 
$LANG['rulesengine'][12]="Campuri"; 
$LANG['rulesengine'][13]="Valoare"; 
$LANG['rulesengine'][14]="Conditie"; 
$LANG['rulesengine'][15]="Motiv"; 
$LANG['rulesengine'][16]="Criteriu"; 
$LANG['rulesengine'][17]="Reguli"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Entitatea si drepturile atribuire normelor"; 
$LANG['rulesengine'][20]="Rules applied"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Repartizeaza"; 
$LANG['rulesengine'][23]="Local rules"; 
$LANG['rulesengine'][24]="Tipuri de reguli"; 
$LANG['rulesengine'][25]="Computer's name"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Business rules for tickets"; 
$LANG['rulesengine'][29]="Lista de reguli"; 
$LANG['rulesengine'][30]="Actiune"; 
$LANG['rulesengine'][33]="Dezinstaleaza dictionarul"; 
$LANG['rulesengine'][35]="Dictionarul de software"; 
$LANG['rulesengine'][36]="Dictionarul producatorilor"; 
$LANG['rulesengine'][37]="Reguli de atribire a unei categorii de software-uri"; 
$LANG['rulesengine'][38]="Recalculeaza"; 
$LANG['rulesengine'][40]="Categoria"; 
$LANG['rulesengine'][41]="Validare"; 
$LANG['rulesengine'][42]="SI"; 
$LANG['rulesengine'][43]="SAU"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Assign: equipment by IP address"; 
$LANG['rulesengine'][47]="Assign: equipment by name + domain"; 
$LANG['rulesengine'][48]="Assign equipment"; 
$LANG['rulesengine'][49]="Assign: equipment by MAC address"; 
$LANG['rulesengine'][50]="Dictionarul modelelor de calculatoare"; 
$LANG['rulesengine'][51]="Dictionarul modelelor de monitoare"; 
$LANG['rulesengine'][52]="Dictionarul modelelor de telefoane"; 
$LANG['rulesengine'][53]="Dictionarul modelelor de periferice"; 
$LANG['rulesengine'][54]="Dictionarul modelelor de imprimanta"; 
$LANG['rulesengine'][55]="Dictionarul tipurilor de retele"; 
$LANG['rulesengine'][56]="Exemple"; 
$LANG['rulesengine'][60]="Dictionarul tipurilor de calculatoate"; 
$LANG['rulesengine'][61]="Dictionarul tipurilor de calculatoare"; 
$LANG['rulesengine'][62]="Dictionarul tipurilor de telefoane"; 
$LANG['rulesengine'][63]="Dictionarul tipurilor de periferice"; 
$LANG['rulesengine'][64]="Dictionarul tipurilor de imprimanta"; 
$LANG['rulesengine'][65]="Dictionarul tipurilor de dispozitive de retea"; 
$LANG['rulesengine'][66]="Tipuri"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Dictionarul Service Pack"; 
$LANG['rulesengine'][69]="Dictionarul versiunilor OS"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Rederuleaza dictionarul"; 
$LANG['rulesengine'][77]="Dictionare"; 
$LANG['rulesengine'][78]="Varianta"; 
$LANG['rulesengine'][79]="Add the result from regular expression"; 
$LANG['rulesengine'][80]="Dictionar global"; 
$LANG['rulesengine'][81]="Articolul rezultat"; 
$LANG['rulesengine'][82]="Detaliile rezultatului"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Testeaza motorul de reguli"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Software sters de dictionarul GLPI"; 
$LANG['rulesengine'][90]="Lucru în desfășurare..."; 
$LANG['rulesengine'][91]="Munca incheiata."; 
$LANG['rulesengine'][92]="Atentie, inainte sa rulati dictionarul"; 
$LANG['rulesengine'][93]="Atenție! Această operațiune poate trimite software-ul în coșul de gunoi.<br>Informați-vă utilizatorii."; 
$LANG['rulesengine'][94]="Fuziune"; 
$LANG['rulesengine'][95]="Alegerea producatorului"; 
$LANG['rulesengine'][96]="Rederuleaza dictionarul pentru producator(i)<br> ( ----- = Toate)"; 
$LANG['rulesengine'][97]="Nici un element pentru a fi testat"; 
$LANG['rulesengine'][100]="Informatii cache"; 
$LANG['rulesengine'][102]="Denumirea regulei"; 
$LANG['rulesengine'][103]="Obiecte in cach"; 
$LANG['rulesengine'][104]="Valoare primara"; 
$LANG['rulesengine'][105]="Valoare modificata"; 
$LANG['rulesengine'][106]="Neschimbat"; 
$LANG['rulesengine'][107]="Inactiv"; 
$LANG['rulesengine'][108]="Origenal"; 
$LANG['rulesengine'][110]="Desemnarea drepturilor"; 
$LANG['rulesengine'][111]="Repartizarea entitatilor"; 
$LANG['rulesengine'][112]="Desemnarea drepturile si entitatilor"; 
$LANG['rulesengine'][120]="Motorul se opreste la prima regula verificata."; 
$LANG['rulesengine'][121]="Motorul trateaza toate criteriile."; 
$LANG['rulesengine'][122]="Motorul trece rezultatul unei actiuni, urmatorului criteriu."; 
$LANG['rulesengine'][130]="Entity from LDAP"; 
$LANG['rulesengine'][131]="Entity from TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entity from domain"; 
$LANG['rulesengine'][134]="Reject email (without email response)"; 
$LANG['rulesengine'][135]="Reject email (with email response)"; 
$LANG['rulesengine'][138]="LDAP criterias"; 
$LANG['rulesengine'][140]="Add a criterium"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="User with a single profile"; 
$LANG['rulesengine'][146]="User featuring the profile"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="Mail domain is known"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Cauta"; 
$LANG['search'][1]="for all"; 
$LANG['search'][2]="contine"; 
$LANG['search'][4]="ordonate dupa"; 
$LANG['search'][8]="Data  de inceput"; 
$LANG['search'][9]="Data de finalizare"; 
$LANG['search'][10]="in"; 
$LANG['search'][11]="Elemente vizualizate"; 
$LANG['search'][12]="Indicate an ended date"; 
$LANG['search'][15]="Nici un obiect gasit"; 
$LANG['search'][16]="Cel putin"; 
$LANG['search'][17]="Adauga un criteriu de cautare"; 
$LANG['search'][18]="Sterge un criteriu de cautare"; 
$LANG['search'][19]="Adauga un criteriu de cautare global"; 
$LANG['search'][20]="Sterge un criteriu de cautare global"; 

$LANG['setup'][0]="Casete derulante"; 
$LANG['setup'][2]="Adauga un utilizator GLPI..."; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Tipuri de calculatoare"; 
$LANG['setup'][5]="Sistem de operare"; 
$LANG['setup'][6]="Personalization"; 
$LANG['setup'][9]="Interfata retea"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Nume utilizator"; 
$LANG['setup'][19]="Parola"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Followed private for default"; 
$LANG['setup'][40]="Private tasks by default"; 
$LANG['setup'][41]="Selectati limba"; 
$LANG['setup'][42]="Tipuri de retea"; 
$LANG['setup'][43]="Tipuri de imprimanta"; 
$LANG['setup'][44]="Tipuri de monitor"; 
$LANG['setup'][45]="Tipul carcasei"; 
$LANG['setup'][46]="Default value"; 
$LANG['setup'][47]="Default chart format"; 
$LANG['setup'][48]="Default values"; 
$LANG['setup'][62]="Selectati categoria pentru configurare"; 
$LANG['setup'][63]="Atentie: sunteti pe cale sa stergeti o eticheta folosita la unul sau mai multe elemente"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="Puteti de asemenea inlocui toate evenimentele acestui antet cu altele:"; 
$LANG['setup'][67]="Autentificare externa"; 
$LANG['setup'][69]="Tipuri de dispozitive"; 
$LANG['setup'][70]="Setari generale"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Nod de retea"; 
$LANG['setup'][74]="Nu puteti sterge aceasta locatie pentru ca are sub-locatii"; 
$LANG['setup'][75]="Ca fiul al"; 
$LANG['setup'][79]="Categorii de probleme"; 
$LANG['setup'][80]="Tip de terti"; 
$LANG['setup'][81]="Antetele unui document"; 
$LANG['setup'][82]="Tipul contactului"; 
$LANG['setup'][83]="Starea obiectului"; 
$LANG['setup'][84]="Tip cartus"; 
$LANG['setup'][85]="Tipul contractului"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Knowledge base categories"; 
$LANG['setup'][88]="Retea"; 
$LANG['setup'][89]="Domeniu"; 
$LANG['setup'][90]="VLAN-uri"; 
$LANG['setup'][91]="Modele de calculatoare"; 
$LANG['setup'][92]="Tip de consumabile"; 
$LANG['setup'][93]="Interfata Hard Disk"; 
$LANG['setup'][94]="Modele de monitoare"; 
$LANG['setup'][95]="Modele de retea"; 
$LANG['setup'][96]="Modele de imprimante"; 
$LANG['setup'][97]="Modele de periferice"; 
$LANG['setup'][98]="Tasks category"; 
$LANG['setup'][99]="Building number"; 
$LANG['setup'][100]="Room number"; 
$LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
$LANG['setup'][102]="Nivel de logare"; 
$LANG['setup'][103]="1- Critic (doar eroare de logare)"; 
$LANG['setup'][104]="2- Servar (Nefolosit)"; 
$LANG['setup'][105]="3- Important (logare reușită)"; 
$LANG['setup'][106]="4- Instintare (Adauga, Sterge, Urmarire)"; 
$LANG['setup'][107]="5- Complet (Tot/Toate)"; 
$LANG['setup'][109]="Cât timp vor fi ținute logurile în baza de date (în zile, 0 pentru infinit)"; 
$LANG['setup'][110]="Afișează problemele noi după deschiderea sesiunii"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Limba implicita"; 
$LANG['setup'][114]="Culoarea prioritara"; 
$LANG['setup'][115]="Limita implicita a cartuselor si consumabilelor numarate"; 
$LANG['setup'][116]="Repartizare automata a problemei personalului tehnic ce este responsabil"; 
$LANG['setup'][117]="Autorizeaza vizualizarea de catre utilizatorii anonimi a Intrebarilor Frecvente"; 
$LANG['setup'][118]="Textul paginii de logare"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Adauga automat un utilizator unei autentificari exterioare"; 
$LANG['setup'][125]="... Dintr-o sursă externă"; 
$LANG['setup'][126]="Adauga automat un utilizator unei surse externe"; 
$LANG['setup'][127]="Autocompletion of text fields"; 
$LANG['setup'][128]="Format data"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Number of days this action logs are stored"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="Activeaza modul OCSNG"; 
$LANG['setup'][134]="Modul OCSNG"; 
$LANG['setup'][135]="Normal"; 
$LANG['setup'][136]="Traducere"; 
$LANG['setup'][137]="Depanare"; 
$LANG['setup'][138]="Utilizeaza GLPI in Mode"; 
$LANG['setup'][139]="Comun"; 
$LANG['setup'][140]="Tipuri"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Planificare pe ore"; 
$LANG['setup'][149]="Numarul de zecimale in sume"; 
$LANG['setup'][150]="Formatul numarului"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (pentru legaturi neanonime)"; 
$LANG['setup'][156]="Parola (pentru legaturi neanonime)"; 
$LANG['setup'][157]="Extensia LDAP a parser-ului PHP nu este instalata"; 
$LANG['setup'][158]="Imposibil de utilizat LDAP ca sursa externa de conexiune"; 
$LANG['setup'][159]="Filtru de conexiune"; 
$LANG['setup'][162]="Configurare IMAP/POP"; 
$LANG['setup'][164]="Numele gazdei IMAP/POP (adresa utilizatorilor este de genul logare@aceastagazda)"; 
$LANG['setup'][165]="Parser-ul PHP a fost compilat fara functiile IMAP"; 
$LANG['setup'][166]="Imposibil de utilizat IMAP/POP ca sursa externa de conexiune"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Optiuni de conexiune"; 
$LANG['setup'][169]="Dosarul e-mail (opțional, de obicei INBOX)"; 
$LANG['setup'][170]="Parametru rezultat din conexiune"; 
$LANG['setup'][171]="Port (optional)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="Gazda CAS"; 
$LANG['setup'][175]="Port"; 
$LANG['setup'][176]="Directorul radacina (optional)"; 
$LANG['setup'][177]="Configurare CAS"; 
$LANG['setup'][178]="Extensiile CURL sau DOXML pentru parser-ul PHP nu sunt instalate"; 
$LANG['setup'][179]="Imposibil de utilizat CAS ca sursa externa de conexiune"; 
$LANG['setup'][180]="Utilizeaza TLS"; 
$LANG['setup'][181]="ldap_start_tls nu exista"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Fus orar"; 
$LANG['setup'][190]="Certificare x509"; 
$LANG['setup'][191]="atributul E-mail-ului pentru x509"; 
$LANG['setup'][192]="Activat"; 
$LANG['setup'][193]="Câmpul memorează conectarea în matricea _SERVER"; 
$LANG['setup'][194]="Additional informations retrieval from LDAP directory"; 
$LANG['setup'][195]="Pastreaza statusul"; 
$LANG['setup'][196]="Clear status"; 
$LANG['setup'][197]="Copiaza statusul computerului"; 
$LANG['setup'][198]="Seteaza statusul"; 
$LANG['setup'][199]="Remove the domain of login in form login@domain"; 
$LANG['setup'][200]="Infinite"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Administrator de E-mail"; 
$LANG['setup'][204]="Semnatura E-mail-ului"; 
$LANG['setup'][205]="E-mail-ul a fost trimis catre administrator"; 
$LANG['setup'][206]="Incercarea de a trimite E-mail administratorului a esuat"; 
$LANG['setup'][207]="Raspunsul administratorului la E-mail (daca este necesar)"; 
$LANG['setup'][217]="Functia PHP de mail este necunoscuta sau nu este activata pe acest sistem"; 
$LANG['setup'][218]="Este necesara folosirea SMTP"; 
$LANG['setup'][219]="Permite postarea problemelor de la utilizatori anonimi (helpdesk.hml, colector)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="Limita a programului pentru planificare"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Câmp de logare"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Folosirea unui server SMTP pentru a trimite e-mailuri"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="Nume utilizator SMTP (opțional)"; 
$LANG['setup'][235]="Parola SMTP (opțional)"; 
$LANG['setup'][236]="Fostul responsabil însărcinat cu rezolvarea problemei"; 
$LANG['setup'][237]="Administrator"; 
$LANG['setup'][239]="Tehnicianul raspunzator de aceasta problema"; 
$LANG['setup'][240]="Optiuni de notificare"; 
$LANG['setup'][241]="Nici un criteriu personal. Creati parametrii personali?"; 
$LANG['setup'][242]="Optiuni de avertizare"; 
$LANG['setup'][243]="Atentionari pentru consumabile"; 
$LANG['setup'][244]="Atentionari pentru cartuse"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Atentionari pentru contracte"; 
$LANG['setup'][247]="Atentionari pentru informatiile financiare"; 
$LANG['setup'][248]="Grupul responsabil cu rezolvarea problemei"; 
$LANG['setup'][249]="Solicitantul grupului"; 
$LANG['setup'][250]="Lista implicita a campurilor de cautare"; 
$LANG['setup'][252]="Selectati obiectele implicite ce vor fi afisate"; 
$LANG['setup'][253]="Filtru pentru cautarea intr-un grup"; 
$LANG['setup'][254]="Tipul cautarii"; 
$LANG['setup'][255]="Atribut de grup continand utilizatorii"; 
$LANG['setup'][256]="In utilizatori"; 
$LANG['setup'][257]="In grupuri"; 
$LANG['setup'][258]="Utilizatori si grupuri"; 
$LANG['setup'][259]="Apartinand grupului"; 
$LANG['setup'][260]="Atributul userului continand grupurile sale"; 
$LANG['setup'][261]="Grupul DN"; 
$LANG['setup'][262]="Foloseste DN pentru cautare"; 
$LANG['setup'][263]="Cauta filtru pentru utilizatori"; 
$LANG['setup'][264]="Atentionari pentru licentele expirate"; 
$LANG['setup'][271]="Restrictioneaza administrarea monitorului"; 
$LANG['setup'][272]="Restrictioneaza administrarea dispozitivului"; 
$LANG['setup'][273]="Restrictioneaza administrarea telefonului"; 
$LANG['setup'][274]="Pentru adaugare manuala"; 
$LANG['setup'][275]="Restrictioneaza administrarea imprimantei"; 
$LANG['setup'][280]="Automatically update of the elements related to the computers"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Copie"; 
$LANG['setup'][284]="Sterge"; 
$LANG['setup'][285]="Do not copy"; 
$LANG['setup'][286]="Do not delete"; 
$LANG['setup'][300]="Verifica daca o noua versiune este disponibila"; 
$LANG['setup'][301]="O noua versiune este disponibila"; 
$LANG['setup'][302]="Este disponibil pe site-ul GLPI-PROJECT.org"; 
$LANG['setup'][303]="Aveți ultima versiune disponibilă"; 
$LANG['setup'][304]="Conexiune esuata. Daca folositi proxy, va rugam sa il configurati."; 
$LANG['setup'][305]="Every day"; 
$LANG['setup'][306]="Verifica noi imbunatatiri"; 
$LANG['setup'][307]="Niciodata"; 
$LANG['setup'][308]="In fiecare saptamana"; 
$LANG['setup'][309]="In fiecare luna"; 
$LANG['setup'][310]="Imposibil de realizat conectarea la site"; 
$LANG['setup'][311]="Esuare in incercarea de a se conecta la serverul proxy"; 
$LANG['setup'][312]="Nu exista date disponibile pe site-ul web"; 
$LANG['setup'][313]="Be careful : there is no default value"; 
$LANG['setup'][350]="Arata la crearea unei probleme"; 
$LANG['setup'][351]="Toate elementele"; 
$LANG['setup'][352]="Alte elemente ce pot fi adaugate la problema"; 
$LANG['setup'][360]="Campuri automatizate (marcate cu *)"; 
$LANG['setup'][400]="Proxy configuration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Crearea implicita a unei rubrici la adaugarea unui document sau a unei probleme"; 
$LANG['setup'][503]="Modele de telefoane"; 
$LANG['setup'][504]="Tipuri de telefoane"; 
$LANG['setup'][505]="Tipul sursei de alimentare a telefoanelor"; 
$LANG['setup'][601]="Valoarea LDAP"; 
$LANG['setup'][602]="Connection to OCSNG database"; 
$LANG['setup'][603]="Adauga un utilizator"; 
$LANG['setup'][604]="Asociat unui grup"; 
$LANG['setup'][606]="Imposibil de adaugat. User-ul exista deja."; 
$LANG['setup'][607]="Asociat uniu profil"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Specificati titlul problemei"; 
$LANG['setup'][611]="Specificati continutul problemei"; 
$LANG['setup'][612]="Specificati categoria din care face parte problema"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Unable to update login. A user already exists."; 
$LANG['setup'][615]="Life cycle of tickets"; 
$LANG['setup'][616]="From \ To"; 
$LANG['setup'][620]="Link"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Attribute representing entity"; 
$LANG['setup'][623]="Import entities from LDAP directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Impossible to configure the notifications : please enable email monitoring"; 
$LANG['setup'][703]="General"; 
$LANG['setup'][704]="Notificari"; 
$LANG['setup'][707]="Alerts on reservations"; 
$LANG['setup'][708]="Alerts on tickets which are not solved since"; 
$LANG['setup'][720]="System informations"; 
$LANG['setup'][721]="Information about system installation and configuration"; 
$LANG['setup'][722]="To copy/paste in your support request"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="Setari MySQL"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Baza de date"; 
$LANG['setup'][803]="Diferenta dintre baza de date principala si cea secundara"; 
$LANG['setup'][806]="Durata maximă de desincronizare (în minute)"; 
$LANG['setup'][807]="Baza de date secundară este desincronizată. Diferenţa este de"; 
$LANG['setup'][808]="Baza de date secundara inafara sync!"; 
$LANG['setup'][809]="Copie MySQL: doar pentru citire"; 
$LANG['setup'][810]="Desynchronization MySQL replication"; 

$LANG['software'][1]="Achizitioneaza versiune"; 
$LANG['software'][2]="Utilizeaza versiunea"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Nelimitat"; 
$LANG['software'][5]="Versiuni"; 
$LANG['software'][6]="Publisher"; 
$LANG['software'][7]="Adauga o versiune"; 
$LANG['software'][8]="Adauga o licenta"; 
$LANG['software'][11]="Licente"; 
$LANG['software'][17]="Software instalat"; 
$LANG['software'][19]="Instalat"; 
$LANG['software'][20]="Ramas"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Actualizeaza"; 
$LANG['software'][30]="Tipuri de licente"; 
$LANG['software'][32]="Expirare"; 
$LANG['software'][44]="Instaleaza software"; 
$LANG['software'][45]="Dezinstaleaza software-ul"; 
$LANG['software'][46]="Associable to a ticket"; 
$LANG['software'][47]="Merging"; 
$LANG['software'][48]="Merge"; 
$LANG['software'][49]="Software deleted after merging"; 
$LANG['software'][50]="Assigned to the computer"; 
$LANG['software'][51]="The number must be 1 to be able to affect"; 

$LANG['softwarecategories'][2]="Software fără categorie"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Categorie de software"; 

$LANG['state'][0]="Stare"; 
$LANG['state'][6]="Tipul obiectului"; 
$LANG['state'][7]="Nici un obiect folosit"; 
$LANG['state'][11]="Rezumat"; 

$LANG['stats'][0]="Selectati starile de afisat"; 
$LANG['stats'][1]="Global"; 
$LANG['stats'][2]="No item to display"; 
$LANG['stats'][3]="Pe obiecte"; 
$LANG['stats'][5]="Numărul problemelor deschise"; 
$LANG['stats'][6]="Timpul mediu de intarziere"; 
$LANG['stats'][7]="Show graphics"; 
$LANG['stats'][11]="Numarul problemelor rezolvate"; 
$LANG['stats'][13]="Numar de probleme"; 
$LANG['stats'][15]="Timpul mediu de intarziere"; 
$LANG['stats'][16]="Numele tehnicianului"; 
$LANG['stats'][20]="Nume utilizator"; 
$LANG['stats'][23]="Nici o stare disponibila"; 
$LANG['stats'][25]="Timpul mediu de rezolvare a problemei"; 
$LANG['stats'][27]="Timpul de rezolvare a problemei"; 
$LANG['stats'][30]="Durata medie de raspuns la probleme"; 
$LANG['stats'][31]="Zi(le)"; 
$LANG['stats'][33]="Min(e)"; 
$LANG['stats'][34]="Secunda(e)"; 
$LANG['stats'][35]="Problema(e)"; 
$LANG['stats'][44]="Numele furnizorului"; 
$LANG['stats'][45]="După hardware"; 
$LANG['stats'][47]="După problemă"; 
$LANG['stats'][48]="(repartizat)"; 
$LANG['stats'][49]="(comentarii)"; 

$LANG['title'][5]="Baza de cunostinte"; 
$LANG['title'][6]="Retea"; 
$LANG['title'][9]="Starea obiectului"; 
$LANG['title'][10]="Comentarii la probleme"; 
$LANG['title'][13]="Informatii utilizator"; 
$LANG['title'][14]="Surse externe de autenificare"; 
$LANG['title'][24]="Asistenta"; 
$LANG['title'][26]="Principal"; 
$LANG['title'][27]="Conexiuni"; 
$LANG['title'][28]="Lista problemelor"; 
$LANG['title'][30]="Componente"; 
$LANG['title'][33]="Link-uri externe"; 
$LANG['title'][34]="Link-uri"; 
$LANG['title'][37]="Notite"; 
$LANG['title'][38]="Istoric"; 
$LANG['title'][40]="Note publice si personale"; 
$LANG['title'][42]="Modificari masive"; 
$LANG['title'][43]="Registru"; 

$LANG['tracking'][1]="Dispozitivele mele"; 
$LANG['tracking'][2]="Sau cautare completa"; 
$LANG['tracking'][3]="Date eronate. Actualizare anulata."; 
$LANG['tracking'][4]="There is no urgency in your ticket, please correct."; 
$LANG['tracking'][8]="Nici o descriere a problemei, va rugam reincercati."; 
$LANG['tracking'][9]="Default for tickets"; 
$LANG['tracking'][10]="Default for mail recipients"; 
$LANG['tracking'][24]="Documentul problemei"; 
$LANG['tracking'][29]="Numar"; 
$LANG['tracking'][30]="Nou"; 
$LANG['tracking'][31]="Procesare (desemnat)"; 
$LANG['tracking'][32]="Procesare (planificate)"; 
$LANG['tracking'][34]="Direct"; 
$LANG['tracking'][35]="Scris"; 
$LANG['tracking'][37]="Pastreaza problemele cand se modifica hardware-ul"; 
$LANG['tracking'][38]="Un E-mail a fost trimis catre"; 
$LANG['tracking'][39]="Visible in the simplified interface"; 

$LANG['transfer'][1]="Transfer"; 
$LANG['transfer'][3]="Daca nu sunt utilizate"; 
$LANG['transfer'][4]="Pentru golirea listei elementelor care urmeaza sa fie transferate"; 
$LANG['transfer'][5]="Puteti continua sa adaugati elemente pentru a fi transferate sau sa transferati acum aceste elemente"; 
$LANG['transfer'][6]="Ganditi-va in a face o copie de siguranta inainte de a transfera elementele."; 
$LANG['transfer'][7]="Elemente de transferat"; 
$LANG['transfer'][8]="Modul de transfer"; 

$LANG['update'][88]="Versiunea dumneavoastră de bază de date nu este compatibilă cu versiunea codului instalat. O actualizare este necesară."; 
$LANG['update'][89]="Ați încercat să folosiți GLPI cu o variantă a bazei de date destinată unei versiuni superioare. Trebuie să instalați versiunea corespunzătoare bazei dumneavoastră de date."; 
$LANG['update'][90]="Eroare in timpul actualizarii bazei de date"; 
$LANG['update'][91]="Atentie !"; 
$LANG['update'][92]="Veti actualiza baza de date GLPI cu numele:"; 
$LANG['update'][93]="Conexiune reusita la baza de date"; 
$LANG['update'][94]="Actualizare reusita,baza de date este la zi"; 
$LANG['update'][95]="Conectarea la baza de date a esuat, verificati parametrii de conectare inclusi in fisierul config_db.php"; 
$LANG['update'][96]="Toti administratorii au drepturi de 'super-admin'. Acest tip de utilizator a fost de asemenea adaugat."; 
$LANG['update'][105]="Inposibil de  realizat actualizarea in felul acesta!!"; 
$LANG['update'][106]="Inapoi la GLPI"; 
$LANG['update'][107]="Trebuie sa continuati cu actualizarea continutul bazei de date"; 
$LANG['update'][130]="Actualizarea loctiilor"; 
$LANG['update'][131]="Noua structura e ierarhica"; 
$LANG['update'][132]="Daca ati folosit caracter de separare il puteti seta sa automatrizati generarea noii ierarhii"; 
$LANG['update'][133]="Puteti de asemenea puteti specificati o locatie radacina care include toate locatiile generate"; 
$LANG['update'][134]="Caracter de separare"; 
$LANG['update'][135]="Locatia radacina"; 
$LANG['update'][136]="Aceasta este noua ierarhie creată. Dacă este OK o puteți valida."; 
$LANG['update'][137]="Ierarhie noua"; 
$LANG['update'][138]="Locatii actuale"; 
$LANG['update'][139]="Optimizing tables"; 
$LANG['update'][140]="Creating indexes"; 
$LANG['update'][141]="Change of the database layout"; 
$LANG['update'][142]="Data migration"; 

$LANG['users'][1]="Titlu"; 
$LANG['users'][2]="Categorie"; 

$LANG['validation'][0]="Approval"; 
$LANG['validation'][1]="Send a Approval request"; 
$LANG['validation'][2]="Status"; 
$LANG['validation'][3]="Request date"; 
$LANG['validation'][4]="Approval date"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Approval comment"; 
$LANG['validation'][7]="Approval(s) for the ticket"; 
$LANG['validation'][9]="Waiting for approval"; 
$LANG['validation'][10]="Refused"; 
$LANG['validation'][11]="Acceptat"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Approval request send to"; 
$LANG['validation'][15]="Ticket waiting for your Approval"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Approval requester"; 
$LANG['validation'][19]="Approval granted"; 
$LANG['validation'][20]="Approval denied"; 
$LANG['validation'][21]="Approver"; 
$LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
$LANG['validation'][26]="Approval request"; 
$LANG['validation'][27]="An approval request has been submitted"; 
$LANG['validation'][28]="Status of the Approval request"; 
$LANG['validation'][29]="If approval is denied, specify a reason"; 
$LANG['validation'][30]="Cancel the approval request to"; 
$LANG['validation'][31]="Update the Approval request to"; 
$LANG['validation'][32]="An answer to a Approval request was produced"; 
$LANG['validation'][33]="Tickets awaiting approval"; 
?>